@@ -241,12 +241,13 @@ class Pip(Module):
         data = rlp.encode([rlp.encode(int(2104)), rlp.encode(module), rlp.encode(name)])
         return parse_data(call_obj(self, from_address, self.web3.pipAddress, data))
 
-    def listParam(self, from_address=None):
+    def listGovernParam(self, module, from_address=None):
         """
-        todo fill
+        Query governance parameter list
+        :param module
         :param from_address: Used to call the rpc call method
         :return:
         todo fill
         """
-        data = rlp.encode([rlp.encode(int(2105))])
+        data = rlp.encode([rlp.encode(int(2106)), rlp.encode(module)])
         return parse_data(call_obj(self, from_address, self.web3.pipAddress, data))
